package ch.hevs.kart.comm.discovery;

import java.io.Serializable;
import java.util.List;

import ch.hevs.kart.comm.protocol.Protocol;
import ch.hevs.kart.comm.transport.Transport;

/**
 * Minimal interface a discovered Kart entity has to implement.
 * 
 * @author Michael Clausen (clm@hevs.ch)
 * @version 2.1 - 2015
 */
public interface DiscoveryEntity extends Serializable {
	/**
	 * Returns the user friendly name of the Kart entity.
	 * 
	 * @return User-friendly name.
	 */
	String getFriendlyName();
	
	/**
	 * Returns a textual description of the Kart entity. This is mostly in the form
	 * 		  "Protocol - Address".
	 * 
	 * @return Entity description.
	 */
	String getDescription();
	
	/**
	 * Returns the class of the transport implementation that has to be instantiated in
	 * 	      order to to create a transport connection to the entity.
	 * 
	 * @return Transport implementation class.
	 */
	Class<? extends Transport> getTransportImplementation();
	
	/**
	 * Returns a list of supported protocols of the entity using the transport protocol 
	 * 		  returned by the method getTransportImplementation().
	 * 
	 * @return List of supported protocol implementation classes.
	 */
	List<Class<? extends Protocol>> getSupportedProtocols();
	
	/**
	 * Checks for equality of another entity with this.
	 * 
	 * @param other	Reference to the other entity to compare this with.
	 * @return True if the entity objects are equal, false otherwise.
	 */
	boolean equals(DiscoveryEntity other);
}
