package ch.hevs.kart.comm.transport.tcp;

import java.net.InetAddress;
import java.util.ArrayList;
import java.util.List;

import ch.hevs.kart.comm.discovery.DiscoveryEntity;
import ch.hevs.kart.comm.protocol.Protocol;
import ch.hevs.kart.comm.protocol.kartv1.KartV1Protocol;
import ch.hevs.kart.comm.transport.Transport;

@SuppressWarnings("serial")
public final class TcpDiscoveryEntity implements DiscoveryEntity {
	public TcpDiscoveryEntity(final String name, final InetAddress host) {
		this.name = name;
		this.host = host;
	}
	
	InetAddress getHost() {
		return host;
	}
	
	String getName() {
		return name;
	}
	
	@Override
	public String getFriendlyName() {
		return name;
	}

	@Override
	public String getDescription() {
		return "TCP " + host.getHostAddress();
	}
	
	@Override
	public Class<? extends Transport> getTransportImplementation() {
		return TcpTransport.class;
	}

	@Override
	public List<Class<? extends Protocol>> getSupportedProtocols() {
		List<Class<? extends Protocol>> protocols = new ArrayList<Class<? extends Protocol>>(1);
		protocols.add(KartV1Protocol.class);
		return protocols;
	}

	@Override
	public boolean equals(final DiscoveryEntity other) {
		return getClass() == other.getClass() &&
			   name.equals(((TcpDiscoveryEntity)other).name) &&
			   host.equals(((TcpDiscoveryEntity)other).host);
	}

	private final InetAddress host;
	private final String name;
}
